@@ -1,3 +1,6 @@
+features_names <- sort(c("type", "properties", "geometry"))
+top_names <- sort(c("type", "crs", "features", "name"))
+
 context("geojson_read")
 
 test_that("geojson_read works with file inputs", {
@@ -9,21 +12,21 @@ test_that("geojson_read works with file inputs", {
   expect_is(aa$crs, "list")
   expect_is(aa$features, "list")
   expect_equal(aa$features[[1]]$type, "Feature")
-  expect_named(aa$features[[1]], c("type", "_id", "properties", "geometry"))
-  expect_named(aa, c("type", "crs", "features"))
+  expect_equal(sort(names(aa$features[[1]])), features_names)
+  expect_equal(sort(names(aa)), top_names)
 })
 
 test_that("geojson_read works with url inputs", {
   skip_on_cran()
   
   url <- "https://raw.githubusercontent.com/glynnbird/usstatesgeojson/master/california.geojson"
-  aa <- geojson_read(url, method = "local")
+  aa <- geojson_read(url)
    
   expect_is(aa, "list")
   expect_equal(aa$type, "FeatureCollection")
   expect_is(aa$features, "list")
   expect_equal(aa$features[[1]]$type, "Feature")
-  expect_named(aa$features[[1]], c("type", "id", "properties", "geometry"))
+  expect_equal(sort(names(aa$features[[1]])), features_names)
 })
 
 test_that("geojson_read works with as.location inputs", {
@@ -35,8 +38,8 @@ test_that("geojson_read works with as.location inputs", {
   expect_is(aa$crs, "list")
   expect_is(aa$features, "list")
   expect_equal(aa$features[[1]]$type, "Feature")
-  expect_named(aa$features[[1]], c("type", "_id", "properties", "geometry"))
-  expect_named(aa, c("type", "crs", "features"))
+  expect_equal(sort(names(aa$features[[1]])), features_names)
+  expect_equal(sort(names(aa)), top_names)
 })
 
 test_that("geojson_read works outputing spatial class object", {
